@@ -1,5 +1,8 @@
 package Data::Unixish::Apply;
 
+our $DATE = '2014-12-10'; # DATE
+our $VERSION = '1.48'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
@@ -7,9 +10,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args filter_args);
 use Module::Load;
-use SHARYANTO::Package::Util qw(package_exists);
-
-our $VERSION = '1.47'; # VERSION
+use Package::MoreUtil qw(package_exists);
 
 our %SPEC;
 
@@ -117,7 +118,7 @@ Data::Unixish::Apply - Apply one or more dux functions to data
 
 =head1 VERSION
 
-This document describes version 1.47 of Data::Unixish::Apply (from Perl distribution Data-Unixish), released on 2014-06-12.
+This document describes version 1.48 of Data::Unixish::Apply (from Perl distribution Data-Unixish), released on 2014-12-10.
 
 =head1 SYNOPSIS
 
@@ -150,11 +151,11 @@ specify arguments to a function, you can use a string.
 
 Example:
 
-    [
-        'sort', # no arguments (all default)
-        'date', # no arguments (all default)
-        ['head', {items=>5}], # specify arguments
-    ]
+ [
+     'sort', # no arguments (all default)
+     'date', # no arguments (all default)
+     ['head', {items=>5}], # specify arguments
+ ]
 
 =item * B<in>* => I<any>
 
@@ -171,13 +172,15 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+ (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixish>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -189,11 +192,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
