@@ -1,5 +1,8 @@
 package Data::Unixish::_pad;
 
+our $DATE = '2014-12-10'; # DATE
+our $VERSION = '1.48'; # VERSION
+
 use 5.010;
 use locale;
 use strict;
@@ -7,12 +10,10 @@ use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 #use Log::Any '$log';
 
-use SHARYANTO::String::Util qw(pad);
+use String::Pad qw(pad);
 use Text::ANSI::Util qw(ta_pad ta_mbpad);
 use Text::WideChar::Util qw(mbpad);
 
-our $VERSION = '1.47'; # VERSION
-
 sub _pad {
     my ($which, %args) = @_;
     my ($in, $out) = ($args{in}, $args{out});
@@ -69,7 +70,7 @@ Data::Unixish::_pad - _pad
 
 =head1 VERSION
 
-This document describes version 1.47 of Data::Unixish::_pad (from Perl distribution Data-Unixish), released on 2014-06-12.
+This document describes version 1.48 of Data::Unixish::_pad (from Perl distribution Data-Unixish), released on 2014-12-10.
 
 =head1 HOMEPAGE
 
@@ -77,7 +78,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -89,11 +90,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
