@@ -9,7 +9,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.47'; # VERSION
+our $VERSION = '1.48'; # VERSION
 
 our %SPEC;
 
@@ -41,7 +41,7 @@ sub grep {
         $callback = sub { $_ =~ $re };
     } elsif (ref($callback) ne 'CODE') {
         if ($args{-cmdline}) {
-            $callback = eval "sub { $callback }";
+            $callback = eval "no strict; no warnings; sub { $callback }";
             die "invalid code for grep: $@" if $@;
         } else {
             die "Please supply coderef (or regex) for 'callback'";
@@ -71,7 +71,7 @@ Data::Unixish::grep - Perl grep
 
 =head1 VERSION
 
-This document describes version 1.47 of Data::Unixish::grep (from Perl distribution Data-Unixish), released on 2014-06-12.
+This document describes version 1.48 of Data::Unixish::grep (from Perl distribution Data-Unixish), released on 2014-12-10.
 
 =head1 SYNOPSIS
 
@@ -105,7 +105,7 @@ Arguments ('*' denotes required arguments):
 
 The callback code or regexp to use.
 
-=item * B<in> => I<any>
+=item * B<in> => I<array>
 
 Input stream (e.g. array or filehandle).
 
@@ -126,6 +126,8 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+ (any)
+
 =head1 SEE ALSO
 
 grep(1)
@@ -136,7 +138,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -148,11 +150,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
