@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.47'; # VERSION
+our $VERSION = '1.48'; # VERSION
 
 our %SPEC;
 
@@ -57,19 +57,19 @@ Data::Unixish::lc - Convert text to lowercase
 
 =head1 VERSION
 
-This document describes version 1.47 of Data::Unixish::lc (from Perl distribution Data-Unixish), released on 2014-06-12.
+This document describes version 1.48 of Data::Unixish::lc (from Perl distribution Data-Unixish), released on 2014-12-10.
 
 =head1 SYNOPSIS
 
 In Perl:
 
  use Data::Unixish qw(lduxl);
- my @res = lduxl('lc', 'Steven', 'STEVEN'); # => ('steven', 'steven')
+ my @res = lduxl('lc', 'Januar', 'JANUAR'); # => ('januar', 'januar')
 
 In command line:
 
- % echo -e "STEVEN" | dux lc
- steven
+ % echo -e "JANUAR" | dux lc
+ januar
 
 =head1 FUNCTIONS
 
@@ -82,7 +82,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<in> => I<any>
+=item * B<in> => I<array>
 
 Input stream (e.g. array or filehandle).
 
@@ -103,13 +103,15 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+ (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixish>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -121,11 +123,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
