@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.47'; # VERSION
+our $VERSION = '1.48'; # VERSION
 
 our %SPEC;
 
@@ -119,7 +119,7 @@ Data::Unixish::linum - Add line numbers
 
 =head1 VERSION
 
-This document describes version 1.47 of Data::Unixish::linum (from Perl distribution Data-Unixish), released on 2014-06-12.
+This document describes version 1.48 of Data::Unixish::linum (from Perl distribution Data-Unixish), released on 2014-12-10.
 
 =head1 SYNOPSIS
 
@@ -152,17 +152,17 @@ Arguments ('*' denotes required arguments):
 
 Example when set to false:
 
-    1|use Foo::Bar;
-    2|
-    3|sub blah {
-    4|    my %args = @_;
+ 1|use Foo::Bar;
+ 2|
+ 3|sub blah {
+ 4|    my %args = @_;
 
 Example when set to true:
 
-    1|use Foo::Bar;
-     |
-    3|sub blah {
-    4|    my %args = @_;
+ 1|use Foo::Bar;
+  |
+ 3|sub blah {
+ 4|    my %args = @_;
 
 =item * B<format> => I<str> (default: "%4s|")
 
@@ -170,7 +170,7 @@ Sprintf-style format to use.
 
 Example: C<%04d|>.
 
-=item * B<in> => I<any>
+=item * B<in> => I<array>
 
 Input stream (e.g. array or filehandle).
 
@@ -195,6 +195,8 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+ (any)
+
 =head1 SEE ALSO
 
 lins, rins
@@ -205,7 +207,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -217,11 +219,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
