@@ -7,7 +7,7 @@ use warnings;
 #use Log::Any '$log';
 
 use Data::Unixish::Util qw(%common_args);
-our $VERSION = '1.47'; # VERSION
+our $VERSION = '1.48'; # VERSION
 
 our %SPEC;
 
@@ -58,19 +58,19 @@ Data::Unixish::uc - Convert text to uppercase
 
 =head1 VERSION
 
-This document describes version 1.47 of Data::Unixish::uc (from Perl distribution Data-Unixish), released on 2014-06-12.
+This document describes version 1.48 of Data::Unixish::uc (from Perl distribution Data-Unixish), released on 2014-12-10.
 
 =head1 SYNOPSIS
 
 In Perl:
 
  use Data::Unixish qw(lduxl);
- my @res = lduxl('uc', 'steven', 'Steven'); # => ('STEVEN', 'STEVEN')
+ my @res = lduxl('uc', 'januar', 'Januar'); # => ('JANUAR', 'JANUAR')
 
 In command line:
 
- % echo -e "steven" | dux uc
- STEVEN
+ % echo -e "januar" | dux uc
+ JANUAR
 
 =head1 FUNCTIONS
 
@@ -83,7 +83,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<in> => I<any>
+=item * B<in> => I<array>
 
 Input stream (e.g. array or filehandle).
 
@@ -104,13 +104,15 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+ (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixish>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -122,11 +124,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
