@@ -13,8 +13,8 @@ use Module::Load;
 use String::ShellQuote;
 use Test::More 0.96;
 
-our $VERSION = '1.47'; # VERSION
-our $DATE = '2014-06-12'; # DATE
+our $VERSION = '1.48'; # VERSION
+our $DATE = '2014-12-10'; # DATE
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -157,7 +157,7 @@ Test::Data::Unixish - Routines to test Data::Unixish
 
 =head1 VERSION
 
-This document describes version 1.47 of Test::Data::Unixish (from Perl distribution Data-Unixish), released on 2014-06-12.
+This document describes version 1.48 of Test::Data::Unixish (from Perl distribution Data-Unixish), released on 2014-12-10.
 
 =for Pod::Coverage .+
 
@@ -167,7 +167,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -179,11 +179,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
